import Component from '@glimmer/component';
import {tracked} from '@glimmer/tracking';
import {action} from '@ember/object';
import mapboxgl from 'mapbox-gl';

import {inject as service} from '@ember/service';


export default class PathEditorComponent extends Component {

    @service mapboxWs;

    @tracked lat = 0
    @tracked lng = 0 
    @tracked fullDist = 0
    @tracked polyline = []
    startPoint 
    geoJsonPolyline = {
        "geometry": {
            "coordinates": this.polyline,
            "type": "LineString"
        },
        "type": "Feature",
        "properties": {
            "name": "Cyclo path"
        }
    }
    initLayer = false 
    
    @action async mapClicked({target: map, point}) {
        let clickCoord = map.unproject(point);
        this.lat = clickCoord.lat;
        this.lng = clickCoord.lng;
        let newCoord = [this.lng, this.lat];
        this.polyline.push(newCoord);

        if (this.polyline.length == 1) { // First point special processing --> add a marker as starting point
            this.startPoint = new mapboxgl.Marker().setLngLat([this.lng, this.lat]).addTo(map);
        } else {
            /**** Addition for following roads */
            // complete polyline by first retrieving new path though mapbox service
            let previousCoord = this.polyline[this.polyline.length - 2];
            let path = await this.mapboxWs.direction("cycling", previousCoord, newCoord);
            if (path.coords.length > 0) { // Insert intermediate coord in the polyline
                let last = this.polyline.pop();
                for (let i = 0; i < path.coords.length; i++) {
                    this.polyline.push(path.coords[i]);
                }
                this.fullDist += path.dist;
            }
            // Don't put back last point that could be outside the road
            // this.polyline.push(last);
            /** End of addition */
            if (!this.initLayer) {
                map.addSource('cycling-path', {
                    'type': 'geojson',
                    'data': this.geoJsonPolyline
                });
                map.addLayer({
                    'id': 'Drawn_cycling_path',
                    'type': 'line',
                    'source': 'cycling-path',
                    'layout': {
                        'line-cap': 'round'
                    },
                    'paint': {
                        'line-dasharray': [
                            1, 2
                        ],
                        'line-color': '#f77',
                        'line-width': 3
                    }
                });
                this.initLayer = true;
            } else {
                map.getSource('cycling-path').setData(this.geoJsonPolyline);
            }
        }
    }
}
