import Service from '@ember/service';
import axios from 'axios';
import config from '../config/environment';

export default class MapboxWsService extends Service {
  baseUrl = 'https://api.mapbox.com';

  token = config.mapboxToken;

  init() {
    super.init(...arguments);

    this.axios = axios.create(this.config());

    this.load(this.axios);

    this.request = this.axios.get;
    this.get = this.axios.get;
    this.delete = this.axios.delete;
    this.head = this.axios.head;
    this.options = this.axios.options;
    this.post = this.axios.post;
    this.put = this.axios.put;
    this.patch = this.axios.patch;
  }

  client() {
    return this.axios;
  }

  async direction(profile, coord1, coord2) {
    const coords = coord1[0]+','+coord1[1]+';'+coord2[0]+','+coord2[1]
    const urlOptimize = this.baseUrl+'/directions/v5/mapbox/'+profile+'/'+coords+'?geometries=geojson&access_token='+this.token;
    let response = await axios({
      method: 'get',
      url: urlOptimize,
      mode: 'no-cors',
      headers: {
        "Accept": "*/*",
        "content-type": "text/plain",
        "Access-Control-Allow-Origin": "*"
    }
    });
    if (response.status !== 200 && response.data.code !== 'Ok') {
      return { coords: [], dist: 0};
    }  
    return { coords: response.data.routes[0].geometry.coordinates, dist: response.data.routes[0].distance };

  }

  async optimize(profile, coord1, coord2) {
    const coords = coord1[0]+','+coord1[1]+';'+coord2[0]+','+coord2[1]
    const urlOptimize = this.baseUrl+'/optimized-trips/v1/mapbox/'+profile+'/'+coords+'?geometries=geojson&access_token='+this.token;
    let response = await axios({
      method: 'get',
      url: urlOptimize,
      mode: 'no-cors',
      headers: {
        "Accept": "*/*",
        "content-type": "text/plain",
        "Access-Control-Allow-Origin": "*"
    }
    });
    if (response.status !== 200 || response.data.code !== 'Ok') {
      return [];   
    }
    return response.data.trips[0].geometry.coordinates;
  }
  
  headers() {
    return {};
  }

  config() {
    return {
      baseURL: this.baseUrl,
      headers: this.headers()
    };
  }

  load() {
    return true;
  }
}